@@ -1,31 +1,31 @@
 from cone.app import compat
 from cone.app.browser import render_main_template
 from cone.app.browser.actions import ActionContext
-from cone.app.browser.ajax import AjaxEvent
-from cone.app.browser.ajax import AjaxOverlay
-from cone.app.browser.ajax import AjaxPath
 from cone.app.browser.ajax import ajax_continue
 from cone.app.browser.ajax import ajax_form_fiddle
 from cone.app.browser.ajax import ajax_message
+from cone.app.browser.ajax import AjaxEvent
+from cone.app.browser.ajax import AjaxOverlay
+from cone.app.browser.ajax import AjaxPath
 from cone.app.browser.ajax import render_ajax_form
 from cone.app.browser.utils import make_query
 from cone.app.browser.utils import make_url
-from cone.app.browser.utils import node_path
 from cone.app.model import AdapterNode
 from cone.app.model import BaseNode
-from cone.app.model import Properties
 from cone.app.model import get_node_info
+from cone.app.model import Properties
 from cone.app.utils import app_config
-from cone.tile import Tile
+from cone.app.utils import node_path
 from cone.tile import render_template
 from cone.tile import render_tile
+from cone.tile import Tile
 from cone.tile import tile
 from plumber import Behavior
 from plumber import default
 from plumber import override
 from plumber import plumb
-from pyramid.i18n import TranslationStringFactory
 from pyramid.i18n import get_localizer
+from pyramid.i18n import TranslationStringFactory
 from pyramid.view import view_config
 from webob.exc import HTTPFound
 from yafowil.base import factory
@@ -493,7 +493,7 @@ class OverlayEditForm(OverlayForm,
 # deleting
 ###############################################################################
 
-@tile(name='delete', permission="delete")
+@tile(name='delete', permission='delete')
 class DeleteAction(Tile):
     show_confirm_deleted = True
 
