@@ -4,7 +4,7 @@ from cone.app.browser.batch import Batch
 from cone.app.browser.utils import format_date
 from cone.app.browser.utils import make_query
 from cone.app.browser.utils import make_url
-from cone.app.browser.utils import node_path
+from cone.app.utils import node_path
 from cone.tile import Tile
 from node.utils import safe_decode
 from plumber import plumbing
