@@ -16,15 +16,14 @@ from cone.app.security import acl_registry
 from cone.app.utils import app_config
 from cone.app.utils import DatetimeHelper
 from node import schema
-from node.behaviors import Adopt
 from node.behaviors import AsAttrAccess
 from node.behaviors import Attributes
 from node.behaviors import ChildFactory
 from node.behaviors import DefaultInit
 from node.behaviors import Lifecycle
-from node.behaviors import NodeChildValidate
-from node.behaviors import Nodespaces
-from node.behaviors import Nodify
+from node.behaviors import MappingAdopt
+from node.behaviors import MappingConstraints
+from node.behaviors import MappingNode
 from node.behaviors import OdictStorage
 from node.behaviors import Schema
 from node.behaviors import UUIDAware
@@ -170,12 +169,11 @@ class AppNode(Behavior):
 @plumbing(
     AppNode,
     AsAttrAccess,
-    NodeChildValidate,
-    Adopt,
-    Nodespaces,
+    MappingConstraints,
+    MappingAdopt,
     Attributes,
     DefaultInit,
-    Nodify,
+    MappingNode,
     Lifecycle,
     OdictStorage)
 class BaseNode(object):
@@ -232,11 +230,9 @@ class AppSettings(FactoryNode):
 @implementer(IAdapterNode)
 class AdapterNode(BaseNode):
 
-    def __init__(self, model, name, parent):
-        BaseNode.__init__(self, name)
+    def __init__(self, model, name=None, parent=None):
+        BaseNode.__init__(self, name=name, parent=parent)
         self.model = model
-        self.__name__ = name
-        self.__parent__ = parent
 
     def __iter__(self):
         for key in self.model:
@@ -364,6 +360,16 @@ class Translation(Schema, AppEnvironment):
             value = self.name
         return value
 
+    @default
+    @property
+    def canonical_value(self):
+        settings = self.registry.settings or {}
+        lang = settings.get('default_locale_name', 'en')
+        value = self.get(lang)
+        if not value:
+            value = self.name
+        return value
+
 
 o_getattr = object.__getattribute__
 o_setattr = object.__setattr__
