@@ -25,11 +25,13 @@ def test_suite():
     from cone.app.tests import test_browser_form
     from cone.app.tests import test_browser_layout
     from cone.app.tests import test_browser_login
+    from cone.app.tests import test_browser_order
     from cone.app.tests import test_browser_referencebrowser
     from cone.app.tests import test_browser_resources
     from cone.app.tests import test_browser_settings
     from cone.app.tests import test_browser_sharing
     from cone.app.tests import test_browser_table
+    from cone.app.tests import test_browser_translation
     from cone.app.tests import test_browser_utils
     from cone.app.tests import test_browser_workflow
 
@@ -57,11 +59,13 @@ def test_suite():
     suite.addTest(unittest.findTestCases(test_browser_form))
     suite.addTest(unittest.findTestCases(test_browser_layout))
     suite.addTest(unittest.findTestCases(test_browser_login))
+    suite.addTest(unittest.findTestCases(test_browser_order))
     suite.addTest(unittest.findTestCases(test_browser_referencebrowser))
     suite.addTest(unittest.findTestCases(test_browser_resources))
     suite.addTest(unittest.findTestCases(test_browser_settings))
     suite.addTest(unittest.findTestCases(test_browser_sharing))
     suite.addTest(unittest.findTestCases(test_browser_table))
+    suite.addTest(unittest.findTestCases(test_browser_translation))
     suite.addTest(unittest.findTestCases(test_browser_utils))
     suite.addTest(unittest.findTestCases(test_browser_workflow))
 
