@@ -69,7 +69,7 @@ class TestBrowserContextmenu(TileTestCase):
             cmd['invalid'] = Action()
         err = self.expectError(ValueError, add_action)
         expected = (
-            'Only ``LinkAction`` deriving objects can be added '
+            'Only ``TemplateAction`` deriving objects can be added '
             'to ``ContextMenuDropdown`` instances.'
         )
         self.assertEqual(str(err), expected)
@@ -117,7 +117,7 @@ class TestBrowserContextmenu(TileTestCase):
 
     def test_contextmenu(self):
         with self.layer.authenticated('manager'):
-            parent = BaseNode('root')
+            parent = BaseNode(name='root')
             model = parent['model'] = SharingNode()
             model.properties.action_up = True
             model.properties.action_view = True
