@@ -28,11 +28,11 @@ from cone.app.model import UUIDAttributeAware
 from cone.app.model import XMLProperties
 from datetime import datetime
 from node import schema
-from node.behaviors import Adopt
 from node.behaviors import DefaultInit
 from node.behaviors import DictStorage
-from node.behaviors import NodeChildValidate
-from node.behaviors import Nodify
+from node.behaviors import MappingAdopt
+from node.behaviors import MappingConstraints
+from node.behaviors import MappingNode
 from node.interfaces import IInvalidate
 from node.tests import NodeTestCase
 from odict import odict
@@ -399,10 +399,10 @@ class TestModel(NodeTestCase):
 
         @plumbing(
             AppNode,
-            NodeChildValidate,
-            Adopt,
+            MappingConstraints,
+            MappingAdopt,
             DefaultInit,
-            Nodify,
+            MappingNode,
             DictStorage,
             UUIDAsName)
         class UnorderedUUIDAsNameNode(object):
@@ -428,23 +428,32 @@ class TestModel(NodeTestCase):
 
         @plumbing(Translation)
         class TranslationNode(BaseNode):
-            allow_non_node_children = True
+            child_constraints = None
 
         translation = TranslationNode(name='translation')
+        self.assertEqual(translation.value, 'translation')
+        self.assertEqual(translation.canonical_value, 'translation')
+
         translation['en'] = u'English Translation'
         translation['de'] = u'German Translation'
-
         self.assertEqual(translation['en'], 'English Translation')
         self.assertEqual(translation['de'], 'German Translation')
 
         self.layer.forget_request()
         self.assertEqual(translation.value, 'English Translation')
+        self.assertEqual(translation.canonical_value, 'English Translation')
+
         self.layer.set_lang('de')
         self.assertEqual(translation.value, 'German Translation')
+        self.assertEqual(translation.canonical_value, 'English Translation')
+
         self.layer.set_lang('en')
         self.assertEqual(translation.value, 'English Translation')
+        self.assertEqual(translation.canonical_value, 'English Translation')
+
         self.layer.set_lang('it')
         self.assertEqual(translation.value, 'translation')
+        self.assertEqual(translation.canonical_value, 'English Translation')
 
     def test_Properties(self):
         # ``Properties`` object can be used for any kind of mapping.
